@@ -1,7 +1,8 @@
 use std::fmt::{Debug, Display};
 
 use std::sync::mpsc::RecvError;
-use cogo::std::channel::{Receiver, Sender};
+use cogo::std::sync::mpsc::{Receiver, Sender};
+
 use crate::Error;
 use crate::error::Result;
 
@@ -103,7 +104,12 @@ macro_rules! chan_stream {
                     sender.send(Some(Ok($v)));
                 }}
             }
-
+            macro_rules! err_end {
+                ($v:expr) => {{
+                    sender.send(Some(Err($v)));
+                    sender.send(None);
+                }}
+            }
             ///end loop
             macro_rules! end {
                 () => {{
