@@ -45,4 +45,6 @@ pub use decode::*;
 pub use encode::*;
 pub use column::*;
 pub use row::*;
-pub use executor::*;
\ No newline at end of file
+pub use executor::*;
+pub use pool::*;
+pub use utils::*;
\ No newline at end of file
